==================================================================
 `xoutil.dim.meta`:mod: -- Meta-definitions for concrete numbers.
==================================================================

.. automodule:: xoutil.dim.meta
   :members: Dimension, Signature, Quantity, Scalar

.. data:: UNIT

   This the constant value ``1``.  It's given this name to emphasize it's the
   canonical unit for a dimension.


.. data:: SCALAR

   The signature of dimensionless quantities.
